Crate kvarn_chute

Structs

Extendible
It’s safe to unwrap on the fmt::Write trait; we’re writing to a String.
Header
IndentCounter
IndentIndenter

Enums

ContinueBehaviour

Functions

exit_with_message
get_headers
make_anchor
process_document
Process the document at the given path.
read_continue
The message is in the beginning of the print so it should be capitalized and contain a punctuation marking the end of a sentence (e.g. .?!).
read_continue_behaviour
The message is in the beginning of the print so it should be capitalized and contain a punctuation marking the end of a sentence (e.g. .?!).
replace_tags
wait_for
Blocks while waiting for the user to press enter, displaying the message specified.
watch
Watch the given directory.

Type Aliases

Tags