Structs
- Extendible
- It’s safe to unwrap on the
fmt::Writetrait; we’re writing to aString. - Header
- Indent
Counter - Indent
Indenter
Enums
Functions
- exit_
with_ message - get_
headers - make_
anchor - process_
document - Process the document at the given path.
- read_
continue - The message is in the beginning of the print so it should be
capitalized and contain a punctuation marking the end of a sentence (e.g.
.?!). - read_
continue_ behaviour - The message is in the beginning of the print so it should be capitalized and contain a punctuation marking the end of a sentence (e.g.
.?!). - replace_
tags - wait_
for - Blocks while waiting for the user to press enter, displaying the message specified.
- watch
- Watch the given directory.